در این بخش آمار کلیدی را در قالب یک نگاشت سه عضوی مشاهده می‌کنید.

| شماره | توضیحات                                           | سمبل                                        |
| ----- | ------------------------------------------------- | ------------------------------------------- |
| 1     | میانگین ارزش معاملات در 3 ماه گذشته               | ave_val_trans_last_3_month                  |
| 2     | میانگین ارزش معاملات در 12 ماه گذشته              | ave_val_trans_last_12_month                 |
| 3     | رتبه ارزش معاملات در 3 ماه گذشته                  | rank_val_trans_last_3_month                 |
| 4     | رتبه ارزش معاملات در 12 ماه گذشته                 | rank_val_trans_last_12_month                |
| 5     | میانگین حجم معاملات در 3 ماه گذشته                | ave_vol_trans_last_3_month                  |
| 6     | میانگین حجم معاملات در 12 ماه گذشته               | ave_vol_trans_last_12_month                 |
| 7     | رتبه حجم معاملات در 3 ماه گذشته                   | rank_vol_trans_last_3_month                 |
| 8     | رتبه حجم معاملات در 12 ماه گذشته                  | rank_vol_trans_last_12_month                |
| 9     | میانگین دفعات معاملات روزانه در 3 ماه گذشته       | ave_numof_trans_last_3_month                |
| 10    | میانگین دفعات معاملات روزانه در 12 ماه گذشته      | ave_numof_trans_last_12_month               |
| 11    | رتبه دفعات معاملات روزانه در 3 ماه گذشته          | rank_numof_trans_last_3_month               |
| 12    | رتبه دفعات معاملات روزانه در 12 ماه گذشته         | rank_numof_trans_last_12_month              |
| 13    | قیمت میانگین وزنی آخرین روز - بدون دخالت حجم مبنا | w_ave_price_last_day_normal                 |
| 14    | قیمت میانگین وزنی آخرین روز - با دخالت حجم مبنا   | w_ave_price_last_day_base_vol               |
| 15    | ارزش معاملات آخرین روز                            | val_trans_last_day                          |
| 16    | حجم معاملات آخرین روز                             | vol_trans_last_day                          |
| 17    | دفعات معاملات در آخرین روز                        | numof_trans_last_day                        |
| 18    | تعداد روزهای منفی در 3 ماه گذشته                  | numof_neg_days_last_3_month                 |
| 19    | تعداد روزهای منفی در 12 ماه گذشته                 | numof_neg_days_last_12_month                |
| 20    | درصد روزهای منفی در 3 ماه گذشته                   | percent_neg_days_last_3_month               |
| 21    | درصد روزهای منفی در 12 ماه گذشته                  | percent_neg_days_last_12_month              |
| 22    | رتبه روزهای منفی در 3 ماه گذشته                   | rank_neg_days_last_3_month                  |
| 23    | رتبه روزهای منفی در 12 ماه گذشته                  | rank_neg_days_last_12_month                 |
| 24    | روزهای بدون معامله در 3 ماه گذشته                 | numof_notrade_days_last_3_month             |
| 25    | روزهای بدون معامله در 12 ماه گذشته                | numof_notrade_days_last_12_month            |
| 26    | تعداد روزهای مثبت در 3 ماه گذشته                  | numof_pos_days_last_3_month                 |
| 27    | تعداد روزهای مثبت در 12 ماه گذشته                 | numof_pos_days_last_12_month                |
| 28    | درصد روزهای مثبت در 3 ماه گذشته                   | percent_pos_days_last_3_month               |
| 29    | درصد روزهای مثبت در 12 ماه گذشته                  | percent_pos_days_last_12_month              |
| 30    | رتبه روزهای مثبت در 3 ماه گذشته                   | rank_pos_days_last_3_month                  |
| 31    | رتبه روزهای مثبت در 12 ماه گذشته                  | rank_pos_days_last_12_month                 |
| 32    | روزهای با معامله در 3 ماه گذشته                   | numof_trade_days_last_3_month               |
| 33    | روزهای با معامله در 12 ماه گذشته                  | numof_trade_days_last_12_month              |
| 34    | رتبه روزهای با معامله در 3 ماه گذشته              | rank_trade_days_last_3_month                |
| 35    | رتبه روزهای با معامله در 12 ماه گذشته             | rank_trade_days_last_12_month               |
| 36    | ارزش شرکت در آخرین روز                            | val_company_last_day                        |
| 37    | رتبه ارزش شرکت در آخرین روز                       | rank_val_company_last_day                   |
| 38    | تعداد روزهای باز در 3 ماه گذشته                   | numof_open_days_last_3_month                |
| 39    | تعداد روزهای باز در 12 ماه گذشته                  | numof_open_days_last_12_month               |
| 40    | درصد روزهای باز در 3 ماه گذشته                    | percent_open_days_last_3_month              |
| 41    | درصد روزهای باز در 12 ماه گذشته                   | percent_open_days_last_12_month             |
| 42    | رتبه روزهای باز در 3 ماه گذشته                    | rank_open_days_last_3_month                 |
| 43    | رتبه روزهای باز در 12 ماه گذشته                   | rank_open_days_last_12_month                |
| 44    | تعداد روزهای بسته در 3 ماه گذشته                  | numof_close_days_last_3_month               |
| 45    | تعداد روزهای بسته در 12 ماه گذشته                 | numof_close_days_last_12_month              |
| 46    | درصد روزهای بسته در 3 ماه گذشته                   | percent_close_days_last_3_month             |
| 47    | درصد روزهای بسته در 12 ماه گذشته                  | percent_close_days_last_12_month            |
| 48    | رتبه روزهای بسته در 3 ماه گذشته                   | rank_close_days_last_3_month                |
| 49    | رتبه روزهای بسته در 12 ماه گذشته                  | rank_close_days_last_12_month               |
| 50    | میانگین حجم خرید حقیقی در 3 ماه گذشته             | ave_vol_individual_buy_last_3_month         |
| 51    | میانگین حجم خرید حقیقی در 12 ماه گذشته            | ave_vol_individual_buy_last_12_month        |
| 52    | رتبه حجم خرید حقیقی در 3 ماه گذشته                | rank_vol_individual_buy_last_3_month        |
| 53    | رتبه حجم خرید حقیقی در 12 ماه گذشته               | rank_vol_individual_buy_last_12_month       |
| 54    | میانگین حجم خرید حقوقی در 3 ماه گذشته             | ave_vol_corporation_buy_last_3_month        |
| 55    | میانگین حجم خرید حقوقی در 12 ماه گذشته            | ave_vol_corporation_buy_last_12_month       |
| 56    | رتبه حجم خرید حقوقی در 3 ماه گذشته                | rank_vol_corporation_buy_last_3_month       |
| 57    | رتبه حجم خرید حقوقی در 12 ماه گذشته               | rank_vol_corporation_buy_last_12_month      |
| 58    | میانگین تعداد خریدار حقیقی در 3 ماه گذشته         | ave_numof_individual_buyer_last_3_month     |
| 59    | میانگین تعداد خریدار حقیقی در 12 ماه گذشته        | ave_numof_individual_buyer_last_12_month    |
| 60    | رتبه تعداد خریدار حقیقی در 3 ماه گذشته            | rank_numof_individual_buyer_last_3_month    |
| 61    | رتبه تعداد خریدار حقیقی در 12 ماه گذشته           | rank_numof_individual_buyer_last_12_month   |
| 62    | میانگین تعداد خریدار حقوقی در 3 ماه گذشته         | ave_numof_corporation_buyer_last_3_month    |
| 63    | میانگین تعداد خریدار حقوقی در 12 ماه گذشته        | ave_numof_corporation_buyer_last_12_month   |
| 64    | رتبه تعداد خریدار حقوقی در 3 ماه گذشته            | rank_numof_corporation_buyer_last_3_month   |
| 65    | رتبه تعداد خریدار حقوقی در 12 ماه گذشته           | rank_numof_corporation_buyer_last_12_month  |
| 66    | میانگین تعداد خریداران در 3 ماه گذشته             | ave_numof_buyer_last_3_month                |
| 67    | میانگین تعداد خریداران در 12 ماه گذشته            | ave_numof_buyer_last_12_month               |
| 68    | رتبه تعداد خریداران در 3 ماه گذشته                | rank_numof_buyer_last_3_month               |
| 69    | رتبه تعداد خریداران در 12 ماه گذشته               | rank_numof_buyer_last_12_month              |
| 70    | میانگین حجم فروش حقیقی در 3 ماه گذشته             | ave_vol_individual_sell_last_3_month        |
| 71    | میانگین حجم فروش حقیقی در 12 ماه گذشته            | ave_vol_individual_sell_last_12_month       |
| 72    | رتبه حجم فروش حقیقی در 3 ماه گذشته                | rank_vol_individual_sell_last_3_month       |
| 73    | رتبه حجم فروش حقیقی در 12 ماه گذشته               | rank_vol_individual_sell_last_12_month      |
| 74    | میانگین حجم فروش حقوقی در 3 ماه گذشته             | ave_vol_corporation_sell_last_3_month       |
| 75    | میانگین حجم فروش حقوقی در 12 ماه گذشته            | ave_vol_corporation_sell_last_12_month      |
| 76    | رتبه حجم فروش حقوقی در 3 ماه گذشته                | rank_vol_corporation_sell_last_3_month      |
| 77    | رتبه حجم فروش حقوقی در 12 ماه گذشته               | rank_vol_corporation_sell_last_12_month     |
| 78    | میانگین تعداد فروشنده حقیقی در 3 ماه گذشته        | ave_numof_individual_seller_last_3_month    |
| 79    | میانگین تعداد فروشنده حقیقی در 12 ماه گذشته       | ave_numof_individual_seller_last_12_month   |
| 80    | رتبه تعداد فروشنده حقیقی در 3 ماه گذشته           | rank_numof_individual_seller_last_3_month   |
| 81    | رتبه تعداد فروشنده حقیقی در 12 ماه گذشته          | rank_numof_individual_seller_last_12_month  |
| 82    | میانگین تعداد فروشنده حقوقی در 3 ماه گذشته        | ave_numof_corporation_seller_last_3_month   |
| 83    | میانگین تعداد فروشنده حقوقی در 12 ماه گذشته       | ave_numof_corporation_seller_last_12_month  |
| 84    | رتبه تعداد فروشنده حقوقی در 3 ماه گذشته           | rank_numof_corporation_seller_last_3_month  |
| 85    | رتبه تعداد فروشنده حقوقی در 12 ماه گذشته          | rank_numof_corporation_seller_last_12_month |
| 86    | میانگین تعداد فروشندگان در 3 ماه گذشته            | ave_numof_seller_last_3_month               |
| 87    | میانگین تعداد فروشندگان در 12 ماه گذشته           | ave_numof_seller_last_12_month              |
| 88    | رتبه تعداد فروشندگان در 3 ماه گذشته               | rank_numof_seller_last_3_month              |
| 89    | رتبه تعداد فروشندگان در 12 ماه گذشته              | rank_numof_seller_last_12_month             |
